In depth description of core functionalities
============================================

Below is a list of links to the documentation for individual core functionalities. These are not code dependent and should be understandable from a physics/mathematics perspective.

.. toctree::
   :maxdepth: 1

   Geometry
   EnergyNormalization
   FileConversion
   VoronoiTessellation
   Visualization
   Interactivity
